"""Collection of constant global variables for the pixi project.
"""

need_to_clone= {"llvm": {"url": "https://github.com/llvm/llvm-project.git", 
                         "branch": "main"}
                }
